---
name: Feature Request
about: Suggest an enhancement
title: ''
labels: ''
assignees: ''

---

**Description**

Describe the feature.

**Example**

Provide code or pseudo code demonstrating how the feature might work, or how current behavior might be changed.

```python

```

**Platform**

Run the following function (static-frame >= 0.8.1) and provide the results to define your platform and environment:

```python
>>> import static_frame as sf
>>> sf.Platform.display()
```

